@@ -7,9 +7,9 @@ import shrinkage
 
 
 def test_shrink():
-    targets = [shrinkage._target_a, shrinkage._target_b,
-               shrinkage._target_c, shrinkage._target_d,
-               shrinkage._target_f]
+    targets = [shrinkage.target_a, shrinkage.target_b,
+               shrinkage.target_c, shrinkage.target_d,
+               shrinkage.target_f]
 
     def calc_all_norms(seed, mu, r, n):
         np.random.seed(seed)
